Class: Utils::Notion::UpdateDatabasePage

Inherits:
Object
  • Object
show all
Defined in:
lib/bas/utils/notion/update_db_page.rb

Overview

This module is a Notion utility for updating database properties.

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ UpdateDatabasePage

Implements the update database properties process logic to Notion.


Params: * page_id Id of the notion page. * secret Notion secret. * body Request body with the properties to be updated.
returns HTTParty::Response


24
25
26
# File 'lib/bas/utils/notion/update_db_page.rb', line 24

def initialize(options)
  @options = options
end

Instance Method Details

#executeObject



28
29
30
# File 'lib/bas/utils/notion/update_db_page.rb', line 28

def execute
  Utils::Notion::Request.execute(params)
end